using System;
using System.IO;
using BizTalk.BuildGenerator.BuildFrameworks.Default.FileBuilders;
using BizTalk.BuildGenerator.MetaData;

namespace BizTalk.BuildGenerator.BuildFrameworks.Default
{
    /// <summary>
    /// Default build process controller which creates build scripts as per the build generator defaults
    /// </summary>
    public class DefaultBuildProcessController : IBuildProvider
    {
        #region Private methods
        public static void CopyResourceFiles(string destinationPath)
        {
            var sourcePath = AppDomain.CurrentDomain.BaseDirectory + @"\Resources";

            CopyFolder(sourcePath, destinationPath);
        }
        private static void CopyFolder(string sourcePath, string destinationPath)
        {
            var destinationDirectory = new DirectoryInfo(destinationPath);
            CopyFiles(sourcePath, destinationPath);
            foreach (var dir in Directory.GetDirectories(sourcePath))
            {
                var folders = Path.GetFullPath(dir).Split(Path.DirectorySeparatorChar);
                var folderName = folders[folders.GetUpperBound(0)];
                var subDirectory = destinationDirectory.CreateSubdirectory(folderName);
                CopyFolder(dir, subDirectory.FullName);
            }
        }
        private static void CopyFiles(string sourceDirectory, string destinationDirectory)
        {
            foreach (var file in Directory.GetFiles(sourceDirectory))
            {
// ReSharper disable AssignNullToNotNullAttribute
                var destinationFilePath = Path.Combine(destinationDirectory, Path.GetFileName(file));
// ReSharper restore AssignNullToNotNullAttribute
                if (!File.Exists(destinationFilePath))
                    File.Copy(file, destinationFilePath);
            }
        }
        #endregion

        #region IBuildProvider Members
        /// <summary>
        /// Implements the update event
        /// </summary>
        public event BuildProcessUpdate Update;
        /// <summary>
        /// Implements the create build method
        /// </summary>
        /// <param name="args"></param>
        public void CreateBuild(GenerationArgs args)
        {
            //This is no longer required as a path to them will be provided
            //Copy all of the files which dont need to be built
            //CopyResourceFiles(args.OutputFolder); 

            IFileBuilder fileBuilder = new ApplicationPropertiesFileBuilder();
            fileBuilder.Build(args);            
            Update(10);            

            fileBuilder = new CustomTargetsFileBuilder();
            fileBuilder.Build(args);
            Update(20);

            fileBuilder = new CustomPropertiesFileBuilder();
            fileBuilder.Build(args);
            Update(20);

            fileBuilder = new RemoveFromGacFileBuilder();
            fileBuilder.Build(args);
            Update(30);

            fileBuilder = new BuildProjectFileBuilder();
            fileBuilder.Build(args);
            Update(50);

            fileBuilder = new CommonApplicationTargetsFileBuilder();
            fileBuilder.Build(args);
            Update(70);

            fileBuilder = new DebugCmdFileBuilder();
            fileBuilder.Build(args);
            Update(80);

            fileBuilder = new QuickBuildDebugCmdFileBuilder();
            fileBuilder.Build(args);
            Update(90);

            fileBuilder = new ReleaseCmdFileBuilder();
            fileBuilder.Build(args);
            Update(100);
        }

        #endregion        
    
        public string FriendlyName
        {
            get { return @"BizTalk Build Generator - Default Build Engine"; }
        }
    }
}