using Microsoft.VisualStudio.TestTools.UnitTesting;
using SSOTasks = BizTalk.BuildGenerator.Tasks.SSO;
using System.IO;
using BizTalk.BuildGenerator.Tasks.SSO;

namespace BizTalk.BuildGenerator.Tasks.Tests.SSO
{
    /// <summary>
    /// Summary description for SSOTests
    /// </summary>
    [TestClass]
    public class SSOTests : MSBuildTest 
    {        
        /// <summary>
        /// Pretest setup
        /// </summary>
        [TestInitialize]
        public void Setup()
        {            
            GetFileAndWriteToPath("BizTalk.BuildGenerator.Tasks.Tests.SSO.SSOTestBuildScript.msbuild", "SSOTestBuildScript.msbuild");
            GetFileAndWriteToPath("BizTalk.BuildGenerator.Tasks.Tests.SSO.SampleSSOTestData.xml", "SampleSSOTestData.xml");
        }
        /// <summary>
        /// Cleans after test
        /// </summary>
        [TestCleanup]
        public void CleanUp()
        {
            File.Delete("SSOTestBuildScript.msbuild");
            File.Delete("SampleSSOTestData.xml");            
        }
        /// <summary>
        /// Tests the SSO tasks
        /// </summary>
        [TestMethod]
        public void ExecuteSSOMsBuildTest()
        {
            const string ssoApplicationName = "BizTalkBuildGeneratorTestApplication";

            const string arguments = "SSOTestBuildScript.msbuild /t:Build";
            var result = RunMSBuild(arguments);
            Assert.IsTrue(result == 0, "The MSBuild Task failed.");

            var val = SSOConfiguration.Read(ssoApplicationName, "CustomProperty1");
            Assert.IsNotNull(val, "The property value should not be null");
            Assert.IsTrue(val == "This is a sample text value", "The value is not as expected");

            val = SSOConfiguration.Read(ssoApplicationName, "CustomProperty2");
            Assert.IsNotNull(val, "The property2 value should not be null");
            Assert.IsTrue(val == File.ReadAllText("SampleSSOTestData.xml"), "The value is not as expected");

            var deleteApp = new DeleteApplication {ApplicationName = ssoApplicationName};
            deleteApp.Execute();
        }
    }
}
