using System;
using System.Collections.Generic;
using System.Globalization;
using System.Text;
using BizTalk.BuildGenerator.MetaData;
using BizTalk.BuildGenerator.MetaData.ResourceAdapters;

namespace BizTalk.BuildGenerator.CommandBuilders
{
    public class ApplicationResourceCommandBuilder : ICommandBuilder
    {
        private const string AddWebDirectoryCommandFormat =
            "\t\t<Exec Command='BTSTask AddResource /Source:{0} /ApplicationName:$(ProductName) /Type:System.BizTalk:WebDirectory /Overwrite /Destination:{1}'/>";

        private const string AddBindingCommandFormat =
            "\t\t<Exec Command='BTSTask AddResource /Source:{0} /Property:TargetEnvironment=\"{1}\" /ApplicationName:\"$(ProductName)\" /Type:{2} ' />";

        private const string AddBizTalkAssemblyCommandFormat =
            "\t\t<Exec Command='BTSTask AddResource /Source:\"{0}\" /ApplicationName:\"$(ProductName)\" /Type:System.BizTalk:BizTalkAssembly /Overwrite /Destination:\"{1}\" /Options:{2}' />";

        private const string AddAssemblyCommandFormat =
            "\t\t<Exec Command='BTSTask AddResource /Source:\"{0}\" /ApplicationName:\"$(ProductName)\" /Type:System.BizTalk:Assembly /Overwrite /Destination:\"{1}\" /Options:{2}' />";

        private const string CommandTag = "<!-- @DeployResourcesCommand@ -->";

        #region ICommandBuilder Members

        public void Build(GenerationArgs args, StringBuilder fileBuilder)
        {
            StringBuilder commandBuilder = new StringBuilder();

            foreach (ApplicationResource resource in args.ApplicationDescription.Resources)
            {
                string command = string.Empty;
                List<string> commandArgs = new List<string>();

                switch (resource.Type)
                {
                    case ResourceTypes.BizTalkBinding:
                        command = AddBindingCommandFormat;
                        BindingResourceAdapter bindingAdapter = BindingResourceAdapter.Create(resource);
                        commandArgs.Add(bindingAdapter.SourceLocation);
                        commandArgs.Add(bindingAdapter.TargetEnvironment);
                        commandArgs.Add(resource.Type);

                        break;
                    case ResourceTypes.BizTalkAssembly:
                        command = AddBizTalkAssemblyCommandFormat;
                        BizTalkAssemblyResourceAdapter bizTalkAssemblyAdapter =
                            BizTalkAssemblyResourceAdapter.Create(resource);
                        commandArgs.Add(BaseResourceAdapter.FormatResourcePath(bizTalkAssemblyAdapter.SourceLocation));
                        commandArgs.Add(bizTalkAssemblyAdapter.DestinationLocation);
                        commandArgs.Add(bizTalkAssemblyAdapter.Options);

                        break;
                    case ResourceTypes.Assembly:
                        command = AddAssemblyCommandFormat;
                        AssemblyResourceAdapter assemblyAdapter = AssemblyResourceAdapter.Create(resource);
                        commandArgs.Add(BaseResourceAdapter.FormatResourcePath(assemblyAdapter.SourceLocation));
                        commandArgs.Add(assemblyAdapter.DestinationLocation);
                        commandArgs.Add(assemblyAdapter.Options);

                        break;
                    case ResourceTypes.WebDirectory:
                        command = AddWebDirectoryCommandFormat;
                        WebDirectoryResourceAdapter webDirectoryAdapter = WebDirectoryResourceAdapter.Create(resource);
                        commandArgs.Add(webDirectoryAdapter.SourceLocation);
                        commandArgs.Add(webDirectoryAdapter.DestinationLocation);

                        break;
                    case ResourceTypes.Bam:
                        //TODO Add
                        break;

                    case ResourceTypes.File:
                        //TODO Add
                        break;

                    case ResourceTypes.PostProcessingScript:
                        //TODO Add
                        break;

                    case ResourceTypes.PreProcessingScript:
                        //TODO Add
                        break;
                    default:
                        break;
                }

                command = string.Format(CultureInfo.InvariantCulture, command, commandArgs.ToArray());
                commandBuilder.Append(command);
                commandBuilder.Append(Environment.NewLine);
            }

            fileBuilder.Replace(CommandTag, commandBuilder.ToString());
        }

        #endregion
    }
}