using System;
using System.Globalization;
using System.Text;

namespace BizTalk.BuildGenerator.CommandBuilders
{
    /// <summary>
    /// Builds the commands to use BTSTask to apply the binding files to an application
    /// </summary>
    public class BindingFilesCommandBuilder : ICommandBuilder
    {
        private const string ApplyBindingFileCommand =
            "\t\t<Exec Command=\"BTSTask ImportBindings -Source:{0} -ApplicationName:$(ProductName)\" />";

        private const string CommandTag = "<!-- @ApplyBindingsCommand@ -->";

        #region ICommandBuilder Members

        /// <summary>
        /// Implements the build method
        /// </summary>
        /// <param name="args"></param>
        /// <param name="fileBuilder"></param>
        void ICommandBuilder.Build(GenerationArgs args, StringBuilder fileBuilder)
        {
            StringBuilder commandBuilder = new StringBuilder();

            foreach (ApplicationBinding binding in args.ApplicationBindings.BindingFiles)
            {
                string command =
                    string.Format(CultureInfo.InvariantCulture, ApplyBindingFileCommand, binding.BindingFilePath);
                commandBuilder.Append(command);
                commandBuilder.Append(Environment.NewLine);
            }

            fileBuilder.Replace(CommandTag, commandBuilder.ToString());
        }

        #endregion
    }
}