using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using System.Management;
using Microsoft.Build.Utilities;
using Microsoft.Build.Framework;

namespace BizTalk.BuildGenerator.Tasks
{
    /// <summary>
    /// Task to create a send handler
    /// </summary>
    public class DeleteSendHandler : Task
    {
        private string _AdapterName;
        private string _HostName;

        /// <summary>
        /// Host name
        /// </summary>
        [Required]
        public string HostName
        {
            get { return _HostName; }
            set { _HostName = value; }
        }
        /// <summary>
        /// Adapter name
        /// </summary>
        [Required]
        public string AdapterName
        {
            get { return _AdapterName; }
            set { _AdapterName = value; }
        }

        /// <summary>
        /// The execute method
        /// </summary>
        /// <returns></returns>
        public override bool Execute()
        {
            try
            {
                using (ManagementClass handlerManagementClass = new ManagementClass("root\\MicrosoftBizTalkServer", "MSBTS_SendHandler2", null))
                {
                    foreach (ManagementObject handler in handlerManagementClass.GetInstances())
                    {
                        if ((string)handler["AdapterName"] == this._AdapterName
                            && (string)handler["HostName"] == this._HostName)
                        {
                            System.Diagnostics.Trace.WriteLine("Found send handler for host " + this._HostName + " for the adapter " + this._AdapterName);
                            handler.Delete();
                        }
                    }
                }
                return true;
            }
            catch (Exception ex)
            {
                System.Diagnostics.EventLog.WriteEntry(this.GetType().FullName, ex.ToString());
                throw;
            }
        }
    }
}
