using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Build.Utilities;
using System.IO;
using Microsoft.Build.Framework;

namespace BizTalk.BuildGenerator.Tasks.BRE
{
    /// <summary>
    /// Task to remove a vocabulary, if the version is supplied then it will remove the specific version
    /// if not then all versions will be removed
    /// </summary>
    public class RemoveVocabulary : BaseBRETask
    {
        private string _VocabularyName;

        /// <summary>
        /// The name of the policy
        /// </summary>
        [Required]
        public string VocabularyName
        {
            get { return _VocabularyName; }
            set { _VocabularyName = value; }
        }

        /// <summary>
        /// Task execute method
        /// </summary>
        /// <returns></returns>
        public override bool Execute()
        {
            BREManager mgr = base.CreateManager();
            if (this.MajorVersion >= 0 && this.MinorVersion >= 0)
            {
                this.Log.LogMessage("Remove specific vocabulary", null);
                mgr.Remove(RulesEngineObjectType.VocabularyInfo, this._VocabularyName, this.MajorVersion, this.MinorVersion);
            }
            else
            {
                this.Log.LogMessage("Remove all versions of vocabulary", null);
                mgr.Remove(RulesEngineObjectType.VocabularyInfo, this._VocabularyName);
            }
            return true;
        }
    }
}
