using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Build.Framework;
using System.IO;
using Microsoft.EnterpriseSingleSignOn.Interop;

namespace BizTalk.BuildGenerator.Tasks.SSO
{
    /// <summary>
    /// Populates a custom property in an SSO application with data read from a file
    /// </summary>
    public class PopulateApplicationPropertyFromFile : BaseSSOTask
    {
        private string _ApplicationName;
        private string _FilePath;
        private string _PropertyName;        
        /// <summary>
        /// The name of the application property
        /// </summary>
        [Required]
        public string PropertyName
        {
            get { return _PropertyName; }
            set { _PropertyName = value; }
        }
        /// <summary>
        /// The file path for data to populate in the field
        /// </summary>
        [Required]
        public string FilePath
        {
            get { return _FilePath; }
            set { _FilePath = value; }
        }
        /// <summary>
        /// Name of the sso application
        /// </summary>
        [Required]
        public string ApplicationName
        {
            get { return _ApplicationName; }
            set { _ApplicationName = value; }
        }
        /// <summary>
        /// Executes the task
        /// </summary>
        /// <returns></returns>
        public override bool Execute()
        {
            if (!File.Exists(this._FilePath))
                throw new ApplicationException("The file with the property data does not exist");
            
            string data = File.ReadAllText(this._FilePath);
            SSOConfiguration.Write(this._ApplicationName, this._PropertyName, data);
            return true;
        }
    }
}
