using System;
using System.Collections.Generic;
using System.Text;

namespace BizTalk.BuildGenerator
{
    /// <summary>
    /// Used to sort the application resources to have the correct build order
    /// </summary>
    public class ApplicationResourceSorter
    {
        /// <summary>
        /// Sorts the resources
        /// </summary>
        /// <param name="resources"></param>
        public static void Sort(List<ApplicationResource> resources)                       
        {
            Queue<ApplicationResource> tempResources = new Queue<ApplicationResource>();

            foreach (ApplicationResource resource in resources)
            {
                if (resource.DependantResources.Count == 0)
                    tempResources.Enqueue(resource);
            }

            foreach (ApplicationResource resource in resources)
            {
                AddResource(resource, resources, tempResources);
            }
            
            resources.Clear();
            resources.AddRange(tempResources.ToArray());
        }
        /// <summary>
        /// Adds resources 
        /// </summary>
        /// <param name="resource"></param>
        /// <param name="resources"></param>
        /// <param name="tempResources"></param>
        private static void AddResource(ApplicationResource resource, List<ApplicationResource> resources, Queue<ApplicationResource> tempResources)
        {
            if (tempResources.Contains(resource))
                return;

            foreach (ApplicationResource dependancy in resource.DependantResources)            
                AddResource(dependancy, resources, tempResources);            

            tempResources.Enqueue(resource);
        }
    }
}
