using System;
using System.IO;
using BizTalk.BuildGenerator.FileBuilders;

namespace BizTalk.BuildGenerator
{
    /// <summary>
    /// Default build process controller which creates build scripts as per the build generator defaults
    /// </summary>
    public class DefaultBuildProcessController : IBuildProvider
    {
        #region Private methods
        public static void CopyResourceFiles(string destinationPath)
        {
            string SourcePath = AppDomain.CurrentDomain.BaseDirectory + @"\Resources";

            CopyFolder(SourcePath, destinationPath);
        }
        private static void CopyFolder(string sourcePath, string destinationPath)
        {
            DirectoryInfo destinationDirectory = new DirectoryInfo(destinationPath);
            CopyFiles(sourcePath, destinationPath);
            foreach (string dir in Directory.GetDirectories(sourcePath))
            {
                string[] folders = Path.GetFullPath(dir).Split(Path.DirectorySeparatorChar);
                string folderName = folders[folders.GetUpperBound(0)];
                DirectoryInfo subDirectory = destinationDirectory.CreateSubdirectory(folderName);
                CopyFolder(dir, subDirectory.FullName);
            }
        }
        private static void CopyFiles(string sourceDirectory, string destinationDirectory)
        {
            foreach (string file in Directory.GetFiles(sourceDirectory))
            {
                string destinationFilePath = Path.Combine(destinationDirectory, Path.GetFileName(file));
                if (!File.Exists(destinationFilePath))
                    File.Copy(file, destinationFilePath);
            }
        }
        #endregion

        #region IBuildProvider Members
        /// <summary>
        /// Implements the update event
        /// </summary>
        public event BuildProcessUpdate Update;
        /// <summary>
        /// Implements the create build method
        /// </summary>
        /// <param name="args"></param>
        public void CreateBuild(GenerationArgs args)
        {
            IFileBuilder fileBuilder;

            //This is no longer required as a path to them will be provided
            //Copy all of the files which dont need to be built
            //CopyResourceFiles(args.OutputFolder); 

            fileBuilder = new ApplicationPropertiesFileBuilder();
            fileBuilder.Build(args);            
            Update(10);            

            fileBuilder = new CustomTargetsFileBuilder();
            fileBuilder.Build(args);
            Update(20);

            fileBuilder = new CustomPropertiesFileBuilder();
            fileBuilder.Build(args);
            Update(20);

            fileBuilder = new RemoveFromGacFileBuilder();
            fileBuilder.Build(args);
            Update(30);

            fileBuilder = new BuildProjectFileBuilder();
            fileBuilder.Build(args);
            Update(50);

            fileBuilder = new CommonApplicationTargetsFileBuilder();
            fileBuilder.Build(args);
            Update(70);

            fileBuilder = new DebugCmdFileBuilder();
            fileBuilder.Build(args);
            Update(80);

            fileBuilder = new QuickBuildDebugCmdFileBuilder();
            fileBuilder.Build(args);
            Update(90);

            fileBuilder = new ReleaseCmdFileBuilder();
            fileBuilder.Build(args);
            Update(100);
        }

        #endregion        
    }
}