using System.Text;
using BizTalk.BuildGenerator.CommandBuilders;
using BizTalk.BuildGenerator.CommandBuilders.BizTalkHost;

namespace BizTalk.BuildGenerator.FileBuilders
{
    /// <summary>
    /// Builds the App.Build.proj file
    /// </summary>
    public class BuildProjectFileBuilder : IFileBuilder
    {
        private const string FileExtension = ".Build.proj";

        #region IFileBuilder Members

        public void Build(GenerationArgs args)
        {
            StringBuilder fileBuilder = new StringBuilder();
            fileBuilder.Append(Resources.App_Build);
            GenerationTags.ReplaceTags(fileBuilder, args);

            //Do Commands
            ExecuteCommandBuilder(new ApplicationResourceCommandBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new BindingFilesCommandBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new PublishedWebServicesCommandBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new CleanHostCommandBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new CreateHostBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new CreateHostInstanceBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new CreateReceiveHandlerBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new CreateSendHandlerBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new DeleteHostCommandBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new DeleteSendHandlerBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new DeleteReceiveHandlerBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new StartHostCommandBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new StopHostCommandBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new UnitTestsCommandBuilder(), args, fileBuilder);
            ExecuteCommandBuilder(new AddApplicationReferencesCommandBuilder(), args, fileBuilder);
                     
            string filePath = args.OutputFolder + @"\" + args.ApplicationDescription.Name + FileExtension;
            FileHelper.ConfigureForBizTalkInstallVariable(fileBuilder);
            FileHelper.ConfigureForSourceCodeRoot(fileBuilder, args);
            FileHelper.WriteFile(filePath, fileBuilder);
        }

        #endregion

        /// <summary>
        /// Executes the command builder
        /// </summary>
        /// <param name="args"></param>
        /// <param name="sb"></param>
        /// <param name="cmd"></param>
        private void ExecuteCommandBuilder(ICommandBuilder cmd, GenerationArgs args, StringBuilder sb)
        {
            cmd.Build(args, sb);
        }
    }
}