using System.Globalization;
using System.Linq;
using System.Text;
using BizTalk.BuildGenerator.MetaData;

namespace BizTalk.BuildGenerator.BuildFrameworks.Default.CommandBuilders
{
    /// <summary>
    /// Builds the command for calling the unit tests
    /// </summary>
    public class UnitTestsCommandBuilder : ICommandBuilder
    {
        private const string UnitTestsCommand =
            "\t\t<Exec Command='\"$(VS100COMNTOOLS)..\\IDE\\mstest.exe\" {0} /runconfig:{1}' />";

        private const string CommandTag = "<!-- @UnitTestCommand@ -->";
        private const string TestContainerTag = " /testcontainer:{0} ";

        #region ICommandBuilder Members

        /// <summary>
        /// Implements the build method
        /// </summary>
        /// <param name="args"></param>
        /// <param name="fileBuilder"></param>
        public void Build(GenerationArgs args, StringBuilder fileBuilder)
        {
            var containerBuilder = new StringBuilder();

            if (args.UnitTesting.TestContainers.Count > 0)
            {
                foreach (var container in
                    args.UnitTesting.TestContainers.Where(container => !string.IsNullOrEmpty(container.Location)))
                {
                    containerBuilder.Append(
                        string.Format(CultureInfo.InvariantCulture, TestContainerTag,
                                      PathHelper.MakeConfigurable(container.Location)));
                }

                var command =
                    string.Format(CultureInfo.InvariantCulture, UnitTestsCommand, containerBuilder,
                                  args.UnitTesting.TestRunConfigPath);
                fileBuilder.Replace(CommandTag, command);
            }
            else
                fileBuilder.Replace(CommandTag, string.Empty);

        }

        #endregion
    }
}