using System;
using System.IO;
using System.Windows.Forms;
using BizTalk.BuildGenerator.MetaData;
using BizTalk.BuildGenerator.UI.Navigation;

namespace BizTalk.BuildGenerator.UI.UserControls
{
    /// <summary>
    /// Control for the build references
    /// </summary>
    public partial class ReferencesControl : UserControl, IWizardControl
    {
        private BuildReferences _references = new BuildReferences();

        /// <summary>
        /// Ctor
        /// </summary>
        public ReferencesControl()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Registers the build references to use
        /// </summary>
        /// <param name="refs"></param>
        public void RegisterReferences(BuildReferences refs)
        {
            _references = refs;
        }

        #region IWizardControl Members

        /// <summary>
        /// Implements i wizard control
        /// </summary>
        /// <returns></returns>
        public MoveNextResult MoveNext()
        {
            var result = new MoveNextResult {CanMoveNext = ValidateControl()};
            return result;
        }

        #endregion

        /// <summary>
        /// Ensures the right data has been provided
        /// </summary>
        /// <returns></returns>
        private bool ValidateControl()
        {
            if (string.IsNullOrEmpty(_references.TasksPath) ||
                !Directory.Exists(_references.TasksPath))
            {
                MessageBox.Show(@"Please select a valid path for the  tasks");
                return false;
            }            

            return true;
        }

        /// <summary>
        /// Handles the load event
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ReferencesControlLoad(object sender, EventArgs e)
        {
            if (!DesignMode)
                BuildReferencesPropertyGrid.SelectedObject = _references;
        }
    }
}