using System;
using System.Collections.Generic;
using System.Linq;

namespace BizTalk.BuildGenerator.MetaData
{
    /// <summary>
    /// 
    /// </summary>
    /// <remarks>
    /// <Exec Command='BTSTask AddResource /Source:$(DevelopmentBizTalkBindingFile) /Property:TargetEnvironment="Development" /ApplicationName:"$(ProductName)" /Type:System.BizTalk:BizTalkBinding ' />
    ///	<Exec Command='BTSTask AddResource /Source:$(UtilitiesAssemblyPath) /ApplicationName:"$(ProductName)" /Type:System.BizTalk:Assembly /Overwrite /Destination:"$(DeploymentDirectory)\Ukm.Integration.CaseManagement.Utilities.dll" /Options:GacOnAdd,GacOnInstall,GacOnImport' />
    ///		<Exec Command='BTSTask AddResource /Source:$(GeneratedTypesAssemblyPath) /ApplicationName:"$(ProductName)" /Type:System.BizTalk:Assembly /Overwrite /Destination:"$(DeploymentDirectory)\Ukm.Integration.CaseManagement.GeneratedTypes.dll" /Options:GacOnAdd,GacOnInstall,GacOnImport' />
    /// <Exec Command='BTSTask AddResource /Source:$(BizTalkAssemblyPath) /ApplicationName:"$(ProductName)" /Type:System.BizTalk:BizTalkAssembly /Overwrite /Destination:"$(DeploymentDirectory)\Ukm.Integration.CaseManagement.BizTalk.dll" /Options:GacOnAdd,GacOnInstall,GacOnImport' />
    /// 
    /// <!-- UnGac Everything -->
    ///	<Exec Command='"$(GacUtilPath)gacutil" /u Ukm.Integration.CaseManagement.GeneratedType' ContinueOnError="true"/>		
    ///	<Exec Command='"$(GacUtilPath)gacutil" /u Ukm.Integration.CaseManagement.BizTalk' ContinueOnError="true"/>
    ///	<Exec Command='"$(GacUtilPath)gacutil" /u Ukm.Integration.CaseManagement.Utilities' ContinueOnError="true"/>
    /// </remarks>
    [Serializable]
    public class ApplicationResource : IComparable<ApplicationResource>
    {
        private List<ApplicationResource> _dependantResources = new List<ApplicationResource>();
        private string _fullName;
        private List<ResourceProperty> _properties = new List<ResourceProperty>();
        private List<string> _references = new List<string>();
        private string _type;

        public List<ApplicationResource> DependantResources
        {
            get { return _dependantResources; }
            set { _dependantResources = value; }
        }


        public string FullName
        {
            get { return _fullName; }
            set { _fullName = value; }
        }

        public List<string> References
        {
            get { return _references; }
            set { _references = value; }
        }

        public List<ResourceProperty> Properties
        {
            get { return _properties; }
            set { _properties = value; }
        }

        public string Type
        {
            get { return _type; }
            set { _type = value; }
        }

        #region IComparable<ApplicationResource> Members

        /// <summary>
        /// Compares this object to another resource
        /// </summary>
        /// <param name="other"></param>
        /// <returns></returns>
        public int CompareTo(ApplicationResource other)
        {
            if (DependsOn(this, other))
                return 1;
            if (DependsOn(other, this))
                return -1;
            return 0;
        }

        #endregion

        /// <summary>
        /// To String
        /// </summary>
        /// <returns></returns>
        public override string ToString()
        {
            return FullName;
        }

        /// <summary>
        /// Checks if this object depends on another
        /// </summary>
        /// <param name="y"></param>
        /// <returns></returns>
        public bool DependsOn(ApplicationResource y)
        {
            return DependsOn(this, y);
        }

        /// <summary>
        /// Recurses through the dependancies to find if one appembly depends on another in its reference tree
        /// </summary>
        /// <param name="x"></param>
        /// <param name="y"></param>
        /// <returns></returns>
        public static bool DependsOn(ApplicationResource x, ApplicationResource y)
        {
            return x.DependantResources.Select(dependant => x.DependantResources.Contains(y) || DependsOn(dependant, y)).FirstOrDefault();
        }
    }
}